==> knative-model-4.6.2-sources.jar: io/fabric8/knative/serving/v1/ServiceStatusBuilder.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ServiceStatusBuilder extends ServiceStatusFluentImpl<ServiceStatusBuilder> implements VisitableBuilder<ServiceStatus,ServiceStatusBuilder>{

    ServiceStatusFluent<?> fluent;
    Boolean validationEnabled;

    public ServiceStatusBuilder(){
            this(true);
    }
    public ServiceStatusBuilder(Boolean validationEnabled){
            this(new ServiceStatus(), validationEnabled);
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent){
            this(fluent, true);
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ServiceStatus(), validationEnabled);
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent,ServiceStatus instance){
            this(fluent, instance, true);
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent,ServiceStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAddress(instance.getAddress()); 
            fluent.withConditions(instance.getConditions()); 
            fluent.withLatestCreatedRevisionName(instance.getLatestCreatedRevisionName()); 
            fluent.withLatestReadyRevisionName(instance.getLatestReadyRevisionName()); 
            fluent.withObservedGeneration(instance.getObservedGeneration()); 
            fluent.withTraffic(instance.getTraffic()); 
            fluent.withUrl(instance.getUrl()); 
            this.validationEnabled = validationEnabled; 
    }
    public ServiceStatusBuilder(ServiceStatus instance){
            this(instance,true);
    }
    public ServiceStatusBuilder(ServiceStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAddress(instance.getAddress()); 
            this.withConditions(instance.getConditions()); 
            this.withLatestCreatedRevisionName(instance.getLatestCreatedRevisionName()); 
            this.withLatestReadyRevisionName(instance.getLatestReadyRevisionName()); 
            this.withObservedGeneration(instance.getObservedGeneration()); 
            this.withTraffic(instance.getTraffic()); 
            this.withUrl(instance.getUrl()); 
            this.validationEnabled = validationEnabled; 
    }

    public ServiceStatus build(){
            ServiceStatus buildable = new ServiceStatus(fluent.getAddress(),fluent.getConditions(),fluent.getLatestCreatedRevisionName(),fluent.getLatestReadyRevisionName(),fluent.getObservedGeneration(),fluent.getTraffic(),fluent.getUrl());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ServiceStatusBuilder that = (ServiceStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> knative-model-4.9.0-sources.jar: io/fabric8/knative/serving/v1/ServiceStatusBuilder.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ServiceStatusBuilder extends ServiceStatusFluentImpl<ServiceStatusBuilder> implements VisitableBuilder<ServiceStatus,ServiceStatusBuilder>{

    ServiceStatusFluent<?> fluent;
    Boolean validationEnabled;

    public ServiceStatusBuilder(){
            this(true);
    }
    public ServiceStatusBuilder(Boolean validationEnabled){
            this.fluent = this; this.validationEnabled=validationEnabled;
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent){
            this(fluent, true);
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent,Boolean validationEnabled){
            this.fluent = fluent; this.validationEnabled=validationEnabled;
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent,ServiceStatus instance){
            this(fluent, instance, true);
    }
    public ServiceStatusBuilder(ServiceStatusFluent<?> fluent,ServiceStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAddress(instance.getAddress()); 
            fluent.withConditions(instance.getConditions()); 
            fluent.withLatestCreatedRevisionName(instance.getLatestCreatedRevisionName()); 
            fluent.withLatestReadyRevisionName(instance.getLatestReadyRevisionName()); 
            fluent.withObservedGeneration(instance.getObservedGeneration()); 
            fluent.withTraffic(instance.getTraffic()); 
            fluent.withUrl(instance.getUrl()); 
            fluent.withAdditionalProperties(instance.getAdditionalProperties());

            this.validationEnabled = validationEnabled; 
    }
    public ServiceStatusBuilder(ServiceStatus instance){
            this(instance,true);
    }
    public ServiceStatusBuilder(ServiceStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAddress(instance.getAddress()); 
            this.withConditions(instance.getConditions()); 
            this.withLatestCreatedRevisionName(instance.getLatestCreatedRevisionName()); 
            this.withLatestReadyRevisionName(instance.getLatestReadyRevisionName()); 
            this.withObservedGeneration(instance.getObservedGeneration()); 
            this.withTraffic(instance.getTraffic()); 
            this.withUrl(instance.getUrl()); 
            this.withAdditionalProperties(instance.getAdditionalProperties());

            this.validationEnabled = validationEnabled; 
    }

    public ServiceStatus build(){
            ServiceStatus buildable = new ServiceStatus(fluent.getAddress(),fluent.getConditions(),fluent.getLatestCreatedRevisionName(),fluent.getLatestReadyRevisionName(),fluent.getObservedGeneration(),fluent.getTraffic(),fluent.getUrl());
            buildable.setAdditionalProperties(fluent.getAdditionalProperties());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ServiceStatusBuilder that = (ServiceStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
